@@ -52,9 +52,9 @@ typedef enum {
 	VTE_DEBUG_WIDGET_SIZE   = 1 << 21
 } VteDebugFlags;
 
-void _vte_debug_init(void);
+VTE_STATIC void _vte_debug_init(void);
 
-extern VteDebugFlags _vte_debug_flags;
+VTE_EXTERN VteDebugFlags _vte_debug_flags;
 static inline gboolean _vte_debug_on(VteDebugFlags flags) G_GNUC_CONST G_GNUC_UNUSED;
 
 static inline gboolean
@@ -77,7 +77,7 @@ _vte_debug_on(VteDebugFlags flags)
 #include <glib/gstdio.h>
 static void _vte_debug_print(guint flags, const char *fmt, ...)
 {
-	if (_vte_debug_on (flags)) {
+	_VTE_DEBUG_IF(flags) {
 		va_list  ap;
 		va_start (ap, fmt);
 		g_vfprintf (stderr, fmt, ap);
@@ -86,6 +86,10 @@ static void _vte_debug_print(guint flags, const char *fmt, ...)
 }
 #endif
 
+#define _ASSERT_STATIC1(_line, _cond) typedef int _static_assert_on_line_##_line##_failed[(_cond)?1:-1]
+#define _ASSERT_STATIC0(_line, _cond) _ASSERT_STATIC1 (_line, (_cond))
+#define ASSERT_STATIC(_cond) _ASSERT_STATIC0 (__LINE__, (_cond))
+
 G_END_DECLS
 
 #endif
