@@ -573,7 +573,7 @@ _vte_trie_matchx(struct _vte_trie *trie, const gunichar *pattern, gsize length,
 				/* Move past characters which might match this
 				 * part of the string... */
 				while (cclass->multiple &&
-				       ((prospect - pattern) < length) &&
+				       ((gsize)(prospect - pattern) < length) &&
 				       cclass->check(prospect[0], data)) {
 					prospect++;
 				}
@@ -1101,7 +1101,7 @@ main(int argc, char **argv)
 }
 #endif
 
-const struct _vte_matcher_class _vte_matcher_trie = {
+VTE_STATIC const struct _vte_matcher_class _vte_matcher_trie = {
 	(_vte_matcher_create_func)_vte_trie_new,
 	(_vte_matcher_add_func)_vte_trie_add,
 	(_vte_matcher_print_func)_vte_trie_print,
