@@ -19,18 +19,17 @@
 #ifndef vte_vteint_h_included
 #define vte_vteint_h_included
 
-#ident "$Id: vteint.h,v 1.2 2005/08/10 13:29:12 kmaraas Exp $"
 
 #include "vte.h"
 
 G_BEGIN_DECLS
 
-void _vte_terminal_accessible_ref(VteTerminal *terminal);
-char* _vte_terminal_get_selection(VteTerminal *terminal);
-void _vte_terminal_get_start_selection(VteTerminal *terminal, long *x, long *y);
-void _vte_terminal_get_end_selection(VteTerminal *terminal, long *x, long *y);
-void _vte_terminal_select_text(VteTerminal *terminal, long start_x, long start_y, long end_x, long end_y, int start_offset, int end_offset);
-void _vte_terminal_remove_selection(VteTerminal *terminal);
+VTE_STATIC  void _vte_terminal_accessible_ref(VteTerminal *terminal);
+VTE_STATIC  char* _vte_terminal_get_selection(VteTerminal *terminal);
+VTE_STATIC  void _vte_terminal_get_start_selection(VteTerminal *terminal, long *x, long *y);
+VTE_STATIC  void _vte_terminal_get_end_selection(VteTerminal *terminal, long *x, long *y);
+VTE_STATIC  void _vte_terminal_select_text(VteTerminal *terminal, long start_x, long start_y, long end_x, long end_y, int start_offset, int end_offset);
+VTE_STATIC  void _vte_terminal_remove_selection(VteTerminal *terminal);
 
 G_END_DECLS
 
