@@ -21,13 +21,12 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: vteskel.h,v 1.2 2003/05/05 23:27:13 nalin Exp $"
 
 #include "vtedraw.h"
 
 G_BEGIN_DECLS
 
-extern struct _vte_draw_impl _vte_draw_skel;
+VTE_EXTERN const struct _vte_draw_impl _vte_draw_skel;
 
 G_END_DECLS
 
